package com.foreverwin.mesnac.meapi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.foreverwin.mesnac.meapi.model.Operation;
import com.foreverwin.mesnac.meapi.service.OperationService;
import com.foreverwin.modular.core.util.CommonMethods;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 *
 * @author Robert
 * @since 2021-06-03
 */
@RestController
@RequestMapping("/OPERATION")
public class OperationController {

    @Autowired
    public OperationService operationService;

    /**
    * 根据id查询
    *
    * @param id 主键
    * @return
    */
    @ResponseBody
    @GetMapping("/{id:.+}")
    public R getOperationById(@PathVariable String id) {
        return R.ok( operationService.getById(id));
    }

    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getOperationList(Operation operation){
        List<Operation> result;
        QueryWrapper<Operation> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(operation);
        result = operationService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 分页查询数据
     *
     * @param frontPage  分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<Operation> frontPage, Operation operation){
        IPage result;
        QueryWrapper<Operation> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(operation);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                .like(Operation::getHandle, frontPage.getGlobalQuery())
                .or().like(Operation::getSite, frontPage.getGlobalQuery())
                .or().like(Operation::getOperation, frontPage.getGlobalQuery())
                .or().like(Operation::getType, frontPage.getGlobalQuery())
                .or().like(Operation::getSpecialRouterBo, frontPage.getGlobalQuery())
                .or().like(Operation::getStatusBo, frontPage.getGlobalQuery())
                .or().like(Operation::getResourceTypeBo, frontPage.getGlobalQuery())
                .or().like(Operation::getRevision, frontPage.getGlobalQuery())
                .or().like(Operation::getCurrentRevision, frontPage.getGlobalQuery())
                .or().like(Operation::getPcaDashboardMode, frontPage.getGlobalQuery())
                .or().like(Operation::getDefaultNcCodeBo, frontPage.getGlobalQuery())
                .or().like(Operation::getFailureTrackingConfigBo, frontPage.getGlobalQuery())
                .or().like(Operation::getResourceBo, frontPage.getGlobalQuery())
                .or().like(Operation::getReportingStep, frontPage.getGlobalQuery())
                .or().like(Operation::getPrevSite, frontPage.getGlobalQuery())
                .or().like(Operation::getOriginalTransferKey, frontPage.getGlobalQuery())
                .or().like(Operation::getSpecialInstruction, frontPage.getGlobalQuery())
                .or().like(Operation::getReportingCenterBo, frontPage.getGlobalQuery())
                .or().like(Operation::getErpControlKeyBo, frontPage.getGlobalQuery())
                .or().like(Operation::getErpWorkCenterBo, frontPage.getGlobalQuery())
    );
        }
        result = operationService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     * @param operation  传递的实体
     * @return  null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody Operation operation) {
        return R.ok(operationService.save(operation));
    }

    /**
     * 修改
     * @param operation  传递的实体
     * @return  null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody Operation operation) {
        return R.ok(operationService.updateById(operation));
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id){
        return R.ok(operationService.removeById(id));
    }

    /**
     * 批量删除对象
     * @param ids 实体集合ID
     * @return  0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids){
        return R.ok(operationService.removeByIds(ids));
    }

    @ResponseBody
    @GetMapping("/getOperationPageList")
    public R getItemPageList(FrontPage<Operation> frontPage, Operation operation){
        IPage result;
        try {
            String site = CommonMethods.getSite();
            operation.setSite(site);
            QueryWrapper<Operation> queryWrapper = new QueryWrapper<>();
            queryWrapper.setEntity(operation);
            if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
                queryWrapper
                        .like("O.OPERATION", frontPage.getGlobalQuery())
                        .or().like("OT.DESCRIPTION", frontPage.getGlobalQuery())
                        .or().like("RS.STEP_ID",frontPage.getGlobalQuery());
            }
            result = operationService.selectPage(frontPage.getPagePlus(), queryWrapper);
        } catch (Exception e) {
            return R.failed(e.getMessage());
        }
        return R.ok(result);
    }
}