package com.foreverwin.mesnac.meapi.controller;

import com.foreverwin.modular.core.util.R;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.CommonMethods;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.foreverwin.mesnac.meapi.service.SfcService;
import com.foreverwin.mesnac.meapi.model.Sfc;
import java.util.List;

/**
 *
 * @author Leon.L
 * @since 2021-06-02
 */
@RestController
@RequestMapping("/SFC")
public class SfcController {

    @Autowired
    public SfcService sfcService;


    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getSfcList(Sfc sfc){
        List<Sfc> result;
        QueryWrapper<Sfc> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(sfc);
        result = sfcService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 分页查询数据
     *
     * @param frontPage  分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<Sfc> frontPage, Sfc sfc){
        IPage result;
        QueryWrapper<Sfc> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(sfc);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                .like(Sfc::getHandle, frontPage.getGlobalQuery())
                .or().like(Sfc::getSite, frontPage.getGlobalQuery())
                .or().like(Sfc::getSfc, frontPage.getGlobalQuery())
                .or().like(Sfc::getStatusBo, frontPage.getGlobalQuery())
                .or().like(Sfc::getShopOrderBo, frontPage.getGlobalQuery())
                .or().like(Sfc::getItemBo, frontPage.getGlobalQuery())
                .or().like(Sfc::getLocation, frontPage.getGlobalQuery())
                .or().like(Sfc::getLccBo, frontPage.getGlobalQuery())
                .or().like(Sfc::getOriginalStatusBo, frontPage.getGlobalQuery())
                .or().like(Sfc::getQtyMultPerformed, frontPage.getGlobalQuery())
                .or().like(Sfc::getPrevSite, frontPage.getGlobalQuery())
                .or().like(Sfc::getOriginalTransferKey, frontPage.getGlobalQuery())
                .or().like(Sfc::getImmediateArchive, frontPage.getGlobalQuery())
                .or().like(Sfc::getTransferUser, frontPage.getGlobalQuery())
                .or().like(Sfc::getSnDone, frontPage.getGlobalQuery())
                .or().like(Sfc::getAinEquipmentId, frontPage.getGlobalQuery())
    );
        }
        result = sfcService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     * @param sfc  传递的实体
     * @return  null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody Sfc sfc) {
        return R.ok(sfcService.save(sfc));
    }

    /**
     * 修改
     * @param sfc  传递的实体
     * @return  null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody Sfc sfc) {
        return R.ok(sfcService.updateById(sfc));
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id){
        return R.ok(sfcService.removeById(id));
    }

    /**
     * 批量删除对象
     * @param ids 实体集合ID
     * @return  0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids){
        return R.ok(sfcService.removeByIds(ids));
    }
}